OC.L10N.register(
    "templateeditor",
    {
    "Could not load template" : "Ei suutnud malli laadida",
    "Saved" : "Salvestatud",
    "Reset" : "Algseaded",
    "An error occurred" : "Tekkis viga",
    "Sharing email - public link shares (HTML)" : "E-kirjaga jagamine - avalik linkide jagamine (HTML)",
    "Sharing email - public link shares (plain text fallback)" : "E-kirjaga jagamine - avalik linkide jagamine (lihttekstina)",
    "Sharing email (HTML)" : "E-kirjaga jagamine (HTML)",
    "Sharing email (plain text fallback)" : "E-kirjaga jagamine (lihttekstina)",
    "Lost password mail" : "Unustatud parooli kiri",
    "New user email (HTML)" : "Uue kasutaja e-post (HTML)",
    "New user email (plain text fallback)" : "Uue kasutaja e-post (lihttekstina)",
    "Activity notification mail" : "Tegevuste teavituse kiri",
    "Mail Templates" : "Kirja mallid",
    "Theme" : "Teema",
    "Template" : "Mall",
    "Please choose a template" : "Palun vali mall",
    "Save" : "Salvesta"
},
"nplurals=2; plural=(n != 1);");
